@@ -497,7 +497,7 @@ class Outcar(object):
         for ii, i in enumerate(self.data):
             if "Electric field gradients after diagonalization" in i:
                 tmp = ii
-        arr = self.data[tmp + 5: tmp + 5 + nions]
+        arr = self.data[tmp + 5 : tmp + 5 + nions]
         efg_arr = []
         for i in arr:
             if std_conv:
@@ -529,7 +529,7 @@ class Outcar(object):
         for ii, i in enumerate(self.data):
             if "Electric field gradients (V/A^2)" in i:
                 tmp = ii
-        arr = self.data[tmp + 4: tmp + 4 + nions]
+        arr = self.data[tmp + 4 : tmp + 4 + nions]
         efg_arr = []
         for i in arr:
             line = i.split()
@@ -552,7 +552,7 @@ class Outcar(object):
                 in i
             ):
                 tmp = ii
-        arr = self.data[tmp + 4: tmp + 4 + nions]
+        arr = self.data[tmp + 4 : tmp + 4 + nions]
         quad_arr = []
         for i in arr:
             tmp = [i.split()[1], i.split()[2], i.split()[3]]
@@ -1078,12 +1078,9 @@ class Wavecar(object):
                 % (Gvec.shape[0], self._nplws[ikpt - 1], np.prod(self._ngrid))
             )
         else:
-            assert (
-                Gvec.shape[0] == self._nplws[ikpt - 1]
-            ), "No. of planewaves not consistent! %d %d %d" % (
-                Gvec.shape[0],
-                self._nplws[ikpt - 1],
-                np.prod(self._ngrid),
+            assert Gvec.shape[0] == self._nplws[ikpt - 1], (
+                "No. of planewaves not consistent! %d %d %d"
+                % (Gvec.shape[0], self._nplws[ikpt - 1], np.prod(self._ngrid),)
             )
         self._gvec = np.asarray(Gvec, dtype=int)
 
@@ -1274,7 +1271,7 @@ class Vasprun(object):
         for i in range(natoms):
             for j in range(natoms):
                 force_constants[i, j] = hessian[
-                    i * 3: (i + 1) * 3, j * 3: (j + 1) * 3
+                    i * 3 : (i + 1) * 3, j * 3 : (j + 1) * 3
                 ]
         masses = [Specie(i).atomic_mass for i in struct.elements]
         # print("Vasp masses", masses)
@@ -1683,6 +1680,7 @@ class Vasprun(object):
         zero_efermi=True,
         kpoints_file_path="KPOINTS",
         plot=False,
+        filename=None,
     ):
         """Get electronic bandstructure plot."""
         try:
@@ -1709,6 +1707,10 @@ class Vasprun(object):
 
         tmp = 0.0
         info = {}
+        indir_gap = float(self.get_indir_gap[0])
+        print("gap=", indir_gap)
+        info["indir_gap"] = indir_gap
+
         info["efermi"] = float(self.efermi)
         if zero_efermi:
             tmp = float(self.efermi)
@@ -1758,6 +1760,9 @@ class Vasprun(object):
                 else r"$\mathrm{Energy\ (eV)}$"
             )
             plt.ylabel(ylabel)
+            if filename is not None:
+                plt.savefig(filename)
+                plt.close()
         return info
 
     @property
